local media = LibStub("LibSharedMedia-3.0")

function Protwarbar:BuildGui()
	local PWB = Protwarbar:getPWB()
	-- Ragebar frame setup
	RageFrame = CreateFrame("Frame", nil, UIParent)
	RageFrame:SetFrameStrata("BACKGROUND")
	RageFrame:SetBackdrop({bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", tile = false})
	RageFrame:SetPoint("BOTTOMLEFT", PWB.db.profile.x, PWB.db.profile.y)

	-- Ragebar frame movement
	RageFrame:RegisterForDrag('LeftButton')
	RageFrame:SetClampedToScreen(true)
	RageFrame:SetScript("OnDragStart", dragstart)
	RageFrame:SetScript('OnDragStop', dragstop)

	-- Ragebar setup
	RageBar = CreateFrame("StatusBar",nil,RageFrame)
	RageBar:SetOrientation("HORIZONTAL")
	RageBar:SetMinMaxValues(0, UnitPowerMax("player"))
	RageBar:SetValue(UnitPower("player"))
	RageBar:SetAllPoints(RageFrame)

	-- Ragebar text setup
	RageBarText = RageBar:CreateFontString(nil, 'OVERLAY')
	RageBarText:SetPoint("CENTER", RageFrame, 0, 0);
	RageBarText:SetFont(media:Fetch("font", PWB.db.profile.barFont), PWB.db.profile.barFontsize, "OUTLINE")
	RageBarText:SetText(UnitPower("player"))

	PWB.iconFrames = {}
	for i = 1, PWB_ICON_COUNT do
		PWB.iconFrames[i] = Protwarbar:createIcon(PWB.db.profile.icons[i])
	end

	-- Vengeance frame setup
	VengeanceFrame = CreateFrame("Frame", nil, UIParent)
	VengeanceFrame:SetFrameStrata("BACKGROUND")
	VengeanceFrame:SetPoint("BOTTOMLEFT", PWB.db.profile.VenFx, PWB.db.profile.VenFy)
	VengeanceFrame:SetBackdrop({bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", tile = false})

	-- Vengeance frame movement
	VengeanceFrame:RegisterForDrag('LeftButton')
	VengeanceFrame:SetClampedToScreen(true)
	VengeanceFrame:SetScript("OnDragStart", dragstart)
	VengeanceFrame:SetScript('OnDragStop', dragstop)

	-- Vengeance text
	VengeanceText = VengeanceFrame:CreateFontString(nil, 'OVERLAY')
	VengeanceText:SetPoint("LEFT", 4, 0);
	VengeanceText:SetFont(media:Fetch("font", PWB.db.profile.VengeanceFont), PWB.db.profile.VengeanceFontsize, "OUTLINE")
	VengeanceText:SetText(0)

	Protwarbar:UpdateStyling()
	Protwarbar:UpdateVisiblity()
end

function Protwarbar:createIcon(icon, spellid)
	frame = CreateFrame("Frame", nil, UIParent)
	frame:SetFrameStrata("BACKGROUND")
	frame:SetPoint("BOTTOMLEFT", icon.x, icon.y)
	frame:SetBackdrop({bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", tile = false})

	-- Icon frame movement
	frame:RegisterForDrag('LeftButton')
	frame:SetClampedToScreen(true)
	frame:SetScript("OnDragStart", dragstart)
	frame:SetScript('OnDragStop', dragstop)

	-- Icon texture
	frame.texture = frame:CreateTexture()
	frame.texture:SetAllPoints(frame)
	frame.texture:SetTexture(GetSpellTexture(icon.spellid))

	return frame
end

function Protwarbar:UpdateStyling()
	local PWB = Protwarbar:getPWB()

	RageFrame:SetWidth(PWB.db.profile.barWidth)
	RageFrame:SetHeight(PWB.db.profile.barHeight)
	RageFrame:SetMovable(not PWB.db.profile.locked)
	RageFrame:SetBackdropColor(PWB.db.profile.bg.r, PWB.db.profile.bg.g,
		PWB.db.profile.bg.b, PWB.db.profile.bg.a)
	RageFrame:EnableMouse(not PWB.db.profile.locked)

	RageBar:SetStatusBarTexture(media:Fetch("statusbar", PWB.db.profile.barTexture))
	RageBar:SetMinMaxValues(0, UnitPowerMax("player"))
	RageBarText:SetFont(media:Fetch("font", PWB.db.profile.barFont), PWB.db.profile.barFontsize, "OUTLINE")

	for i = 1, PWB_ICON_COUNT do
		PWB.iconFrames[i]:SetWidth(PWB.db.profile.iconsize)
		PWB.iconFrames[i]:SetHeight(PWB.db.profile.iconsize)
		PWB.iconFrames[i]:SetMovable(not PWB.db.profile.locked)
		PWB.iconFrames[i]:EnableMouse(not PWB.db.profile.locked)
	end

	VengeanceFrame:SetWidth(PWB.db.profile.VengeanceWidth)
	VengeanceFrame:SetHeight(PWB.db.profile.VengeanceHeight)
	VengeanceFrame:SetMovable(not PWB.db.profile.locked)  
	VengeanceFrame:EnableMouse(not PWB.db.profile.locked)
	VengeanceText:SetFont(media:Fetch("font", PWB.db.profile.VengeanceFont), PWB.db.profile.VengeanceFontsize, "OUTLINE")


	if PWB.db.profile.locked then
		PWB.combat = false -- disable fake combat
		for i = 1, PWB_ICON_COUNT do
			PWB.iconFrames[i]:SetBackdropColor(1, 1, 1, 0)
		end
		VengeanceFrame:SetBackdropColor(1, 1, 1, 0)
	else
		PWB.combat = true -- enable fake combat to force display UI
		for i = 1, PWB_ICON_COUNT do
			PWB.iconFrames[i]:SetBackdropColor(1, 1, 1, 1)
		end
		VengeanceFrame:SetBackdropColor(1, 1, 1, 1)
	end

end

function Protwarbar:UpdateVisiblity()
	local PWB = Protwarbar:getPWB()
	-- if hideooc is enabled and we are not in combat
	if PWB.db.profile.hideooc and not PWB.combat then
		VengeanceFrame:Hide()
		RageFrame:Hide()
		for i = 1, PWB_ICON_COUNT do
			PWB.iconFrames[i]:Hide()
		end
	else

		-- Hide or show vengeance
		if PWB.db.profile.InformationEnabled and PWB.db.profile.enabled then
			VengeanceFrame:Show()		
		else
			VengeanceFrame:Hide()
		end

		-- Hide or show the helper icons
		if PWB.db.profile.IconsEnabled and PWB.db.profile.enabled then
			for i = 1, PWB_ICON_COUNT do
				if PWB.db.profile.icons[i].enabled then
					PWB.iconFrames[i]:Show()
				else
					PWB.iconFrames[i]:Hide()
				end
			end
		else
			for i = 1, PWB_ICON_COUNT do
				PWB.iconFrames[i]:Hide()
			end
		end

		-- Hide or show the ragebar
		if PWB.db.profile.enabled then
			RageFrame:Show()
		else
			RageFrame:Hide()
		end

	end

end

function dragstart(frame)
	local PWB = Protwarbar:getPWB()
	if not PWB.db.profile.locked then
		frame:StartMoving()
	end
end

function dragstop(frame)
	local PWB = Protwarbar:getPWB()
	frame:StopMovingOrSizing()

	PWB.db.profile.x = RageFrame:GetLeft()
	PWB.db.profile.y = RageFrame:GetBottom()

	for i = 1, PWB_ICON_COUNT do
		PWB.db.profile.icons[i].x = PWB.iconFrames[i]:GetLeft()
		PWB.db.profile.icons[i].y = PWB.iconFrames[i]:GetBottom()
	end

	PWB.db.profile.VenFx = VengeanceFrame:GetLeft()
	PWB.db.profile.VenFy = VengeanceFrame:GetBottom()

end