function Protwarbar:CreateOptions()
	local media = LibStub("LibSharedMedia-3.0")
	local textures = media:List("statusbar")
	local fonts = media:List("font")
	local PWB = Protwarbar:getPWB()

	local L = LibStub("AceLocale-3.0"):GetLocale("Protwarbar")

	local options = {
		type = "group",
		name = "Prot War Bar",
		childGroups = "tab",
		args = {
			group1 = {
				name = L["General"],
				type = "group",
				order = 1,
				args = {
					enable = {
					  order = 1,
				      name = L["Enable"],
				      desc = L["Enables / disables the addon"],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.enabled = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.enabled end
				    },
					locked = {
					  order = 2,
				      name = L["Lock frames"],
				      desc = L["When locked, you can not move the bar"],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.locked = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.locked end
				    },
					desc_110 = {
						type = 'description',
						name = " ",
						order = 10,
					},
					hideooc = {
					  order = 11,
				      name = L["Hide out of combat"],
				      desc = L["Hide the frames when you are out of combat."],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.hideooc = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.hideooc end
				    },
			    },
		    },
		    group2 = {
				name = L["Bar appearance"],
				type = "group",
				order = 2,
				args = {
					desc_pos = {
						type = 'header',
						name = L["Position"],
						order = 1,
					},
				    width = {
				        order = 3,
				    	name = L["Width"],
				    	desc = L["Width of rage bar"],
				    	type = "range",
				    	min = 5,
				    	max = 750,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.barWidth = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.barWidth end
					},
				    height = {
				        order = 4,
				    	name = L["Height"],
				    	desc = L["Height of bar"],
				    	type = "range",
				    	min = 5,
				    	max = 100,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.barHeight = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.barHeight end
					},
					desc_colour = {
						type = 'header',
						name = L["Bar colors"],
						order = 10,
					},					
				    color20 = {
				    	name = L["Color 0 - 19"],
				    	desc = L["Color 0 - 19"],
				    	type = "color",
				    	order = 15,
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		PWB.db.profile.color20.r = r;
					      		PWB.db.profile.color20.g = g;
					      		PWB.db.profile.color20.b = b;
					      		PWB.db.profile.color20.a = a;
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return PWB.db.profile.color20.r, PWB.db.profile.color20.g,
				      								PWB.db.profile.color20.b, PWB.db.profile.color20.a 
				      		   end
					},
				    color60 = {
				    	name = L["Color 20 - 59"],
				    	desc = L["Color 20 - 59"],
				    	type = "color",
				    	order = 16,
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		PWB.db.profile.color60.r = r;
					      		PWB.db.profile.color60.g = g;
					      		PWB.db.profile.color60.b = b;
					      		PWB.db.profile.color60.a = a;
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return PWB.db.profile.color60.r, PWB.db.profile.color60.g,
				      								PWB.db.profile.color60.b, PWB.db.profile.color60.a 
				      		   end
					},
					desc_colour2 = {
						type = 'description',
						name = " ",
						order = 20,
					},						
				    color100 = {
				        order = 27,
				    	name = L["Color 60 - 99"],
				    	desc = L["Color 60 - 99"],
				    	type = "color",
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		PWB.db.profile.color100.r = r;
					      		PWB.db.profile.color100.g = g;
					      		PWB.db.profile.color100.b = b;
					      		PWB.db.profile.color100.a = a;
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return PWB.db.profile.color100.r, PWB.db.profile.color100.g,
				      								PWB.db.profile.color100.b, PWB.db.profile.color100.a 
				      		   end
					},
					colorMax = {
				        order = 28,
				    	name = L["Color full bar"],
				    	desc = L["Color full bar"],
				    	type = "color",
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		PWB.db.profile.colorMax.r = r;
					      		PWB.db.profile.colorMax.g = g;
					      		PWB.db.profile.colorMax.b = b;
					      		PWB.db.profile.colorMax.a = a;
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return PWB.db.profile.colorMax.r, PWB.db.profile.colorMax.g,
				      								PWB.db.profile.colorMax.b, PWB.db.profile.colorMax.a 
				      		   end
					},
					desc_bg_head = {
						type = 'header',
						name = L["Bar colors"],
						order = 30,
					},
				    barTexture = {
				    	name = L["Texture"],
				    	desc = L["Texture for ragebar"],
				    	type = "select",
				    	values = textures,
				    	order = 31,
				      	set = function(info, v)
				      			PWB.db.profile.barTexture = media:List("statusbar")[v]
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return GetLSMIndex("statusbar", PWB.db.profile.barTexture) end
					},
					desc_colour32 = {
						type = 'description',
						name = " ",
						order = 32,
					},						
				    bg = {
				    	name = L["Background color"],
				    	desc = L["Color of bar Background"],
				    	type = "color",
				    	order = 33,
				    	hasAlpha = true,
				      	set = function(info, r, g, b, a) 
					      		PWB.db.profile.bg.r = r;
					      		PWB.db.profile.bg.g = g;
					      		PWB.db.profile.bg.b = b;
					      		PWB.db.profile.bg.a = a;
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return PWB.db.profile.bg.r, PWB.db.profile.bg.g,
				      								PWB.db.profile.bg.b, PWB.db.profile.bg.a 
				      		   end
					},

					desc_bg = {
						type = 'header',
						name = L["Bar text"],
						order = 50,
					},						
				    barFont = {
				    	name = L["Font"],
				    	desc = L["Font for ragebar"],
				    	type = "select",
				    	values = fonts,
				    	order = 51,
				      	set = function(info, v)
				      			PWB.db.profile.barFont = media:List("font")[v]
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return GetLSMIndex("font", PWB.db.profile.barFont) end
					},
					desc_52 = {
						type = 'description',
						name = " ",
						order = 52,
					},						
				    fontsize = {
				        order = 53,
				    	name = L["Font Size"],
				    	desc = L["Size of the font used on the ragebar"],
				    	type = "range",
				    	min = 3,
				    	max = 50,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.barFontsize = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.barFontsize end
					},					
				},
			},
			group3 = {
				name = L["Icons"],
				type = "group",
				order = 3,
				childGroups = "tree",
				args = {
					icons1 = {
						name = L["General"],
						type = "group",
						order = 4,
						args = {
							desc_pos = {
								type = 'header',
								name = L["Icons"],
								order = 1,
							},
							hideicons = {
							  order = 2,
						      name = L["Icons enabled"],
						      desc = L["Display the helper icons."],
							  type = "toggle",
						      set = function(info,val) PWB.db.profile.IconsEnabled = val Protwarbar:RefreshConfig() end,
						      get = function(info) return PWB.db.profile.IconsEnabled end
						    },						
							desc_310 = {
								type = 'description',
								name = " ",
								order = 10,
							},					
						    iconsize = {
						        order = 11,
						    	name = L["Size"],
						    	desc = L["Size of the icons"],
						    	type = "range",
						    	min = 5,
						    	max = 100,
						    	step = 1,
						      	set = function(info,val) PWB.db.profile.iconsize = val Protwarbar:RefreshConfig() end,
						      	get = function(info) return PWB.db.profile.iconsize end
							},
						    iconalpha = {
						        order = 12,
						    	name = L["Alpha when unavailable"],
						    	desc = L["Alpha when unavailable"],
						    	type = "range",
						    	min = 0,
						    	max = 1,
						    	step = 0.01,
						      	set = function(info,val) PWB.db.profile.iconAlpha = val Protwarbar:RefreshConfig() end,
						      	get = function(info) return PWB.db.profile.iconAlpha end
							},

						},
					},
					icon_bs = {
						name = L["Battle Shout"],
						type = "group",
						order = 5,
						args = {
							bs_hide = {
							  order = 2,
						      name = L["Icon enabled"],
						      desc = L["Display this the helper icons"],
							  type = "toggle",
						      set = function(info,val) PWB.db.profile.icons[1].enabled = val Protwarbar:RefreshConfig() end,
						      get = function(info) return PWB.db.profile.icons[1].enabled end
						    },
							bs_oncd = {
							  order = 3,
						      name = L["Hide on cooldown"],
						      desc = L["Hide on cooldown"],
							  type = "toggle",
						      set = function(info,val) PWB.db.profile.icons[1].hideOnCD = val Protwarbar:RefreshConfig() end,
						      get = function(info) return PWB.db.profile.icons[1].hideOnCD end
						    },						
						},
					},
					icon_br = {
						name = L["Berserker Rage"],
						type = "group",
						order = 6,
						args = {
							bs_hide = {
							  order = 2,
						      name = L["Icon enabled"],
						      desc = L["Display this the helper icons"],
							  type = "toggle",
						      set = function(info,val) PWB.db.profile.icons[2].enabled = val Protwarbar:RefreshConfig() end,
						      get = function(info) return PWB.db.profile.icons[2].enabled end
						    },
							bs_oncd = {
							  order = 3,
						      name = L["Hide on cooldown"],
						      desc = L["Hide on cooldown"],
							  type = "toggle",
						      set = function(info,val) PWB.db.profile.icons[2].hideOnCD = val Protwarbar:RefreshConfig() end,
						      get = function(info) return PWB.db.profile.icons[2].hideOnCD end
						    },						
						},
					}					
				},
			},
			group4 = {
				name = L["Information"],
				type = "group",
				order = 4,
				args = {
					enable = {
					  order = 1,
				      name = L["Enable"],
				      desc = L["Enable the information frame"],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.InformationEnabled = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.InformationEnabled end
				    },
					desc_pos = {
						type = 'header',
						name = L["Position"],
						order = 2,
					},
				    venwidth = {
				        order = 3,
				    	name = L["Width"],
				    	desc = L["Width of information frame"],
				    	type = "range",
				    	min = 5,
				    	max = 200,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.VengeanceWidth = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.VengeanceWidth end
					},
				    venheight = {
				        order = 3,
				    	name = L["Height"],
				    	desc = L["Height of information frame"],
				    	type = "range",
				    	min = 5,
				    	max = 200,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.VengeanceHeight = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.VengeanceHeight end
					},
					desc_ven_head = {
						type = 'header',
						name = L["Information text"],
						order = 10,
					},
				    venFont = {
				    	name = L["Font"],
				    	desc = L["Font for information"],
				    	type = "select",
				    	values = fonts,
				    	order = 11,
				      	set = function(info, v)
				      			PWB.db.profile.VengeanceFont = media:List("font")[v]
					      	 	Protwarbar:RefreshConfig() 
				      		end,
				      	get = function(info) return GetLSMIndex("font", PWB.db.profile.VengeanceFont) end
					},
					desc_412 = {
						type = 'description',
						name = " ",
						order = 12,
					},						
				    venfontsize = {
				        order = 13,
				    	name = L["Font Size"],
				    	desc = L["Size of the font used for information"],
				    	type = "range",
				    	min = 3,
				    	max = 50,
				    	step = 1,
				      	set = function(info,val) PWB.db.profile.VengeanceFontsize = val Protwarbar:RefreshConfig() end,
				      	get = function(info) return PWB.db.profile.VengeanceFontsize end
					},	
					desc_420 = {
						type = 'header',
						name = L["Information elements"],
						order = 20,
					},
					enableven = {
					  order = 21,
				      name = L["Display Vengeance"],
				      desc = L["Display Vengeance"],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.VengeanceEnabled = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.VengeanceEnabled end
				    },
				    enablesb = {
					  order = 22,
				      name = L["Display Shield Barrier"],
				      desc = L["Display Shield Barrier"],
					  type = "toggle",
				      set = function(info,val) PWB.db.profile.shieldBarrierEnabled = val Protwarbar:RefreshConfig() end,
				      get = function(info) return PWB.db.profile.shieldBarrierEnabled end
				    },
				},
			},

		},
	}

	return options
end

function GetLSMIndex(t, value)
	local media = LibStub("LibSharedMedia-3.0")

	for k, v in pairs(media:List(t)) do
		if v == value then
			return k
		end
	end
	return nil
end